MethodActionParser class

Constructors

MethodActionParser()

Properties

actionType String
The actionType of the action that this parser can parse.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getModel(Map<String, dynamic> json) MethodCall
Parses a JSON object into a model T.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCall(BuildContext context, MethodCall model) FutureOr
Handles the action based on the model T.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited