actionType property

  1. @override
String get actionType

The actionType of the action that this parser can parse.

This is used to identify the type of the action in the JSON object.

Implementation

@override
String get actionType => 'methodCall';