getModel method

  1. @override
MethodCall getModel(
  1. Map<String, dynamic> json
)

Parses a JSON object into a model T.

This method should be implemented to parse a JSON object into a model. The JSON object is typically a part of the STAC action. The model T should contain all the necessary data to handle the action.

Implementation

@override
MethodCall getModel(Map<String, dynamic> json) {
  return MethodCall(
    pageId: '',
    name: json['name'] as String? ?? '',
    params: json['params'] != null ? serialize(json['params']) : <int>[],
  );
}