onCall method
Handles the action based on the model T.
This method should be implemented to handle the action based on the model.
The model T is the result of the getModel method.
The BuildContext is the current build context.
This method can return a Future if the action is asynchronous.
Implementation
@override
FutureOr<dynamic> onCall(BuildContext context, MethodCall model) {
final methodName = model.name;
String pageId = StacPageScope.of(context);
final finalModel = model.copyWith(pageId: pageId);
if (methodName.isEmpty) return null;
finalModel.sendSignalToRust();
}