ChangeRoute class
- Annotations
Constructors
Properties
Methods
-
bincodeSerialize(
) → Uint8List -
copyWith(
{NavAction? action, String? pageId()?, List< int> ? json()?, String? predicateRouteName()?}) → ChangeRoute -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
BinarySerializer serializer) → void -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Properties
-
latestRustSignal
↔ RustSignalPack<
ChangeRoute> ? -
The latest signal value received from Rust.
This is updated every time a new signal is received.
It can be null if no signals have been received yet.
getter/setter pair
-
rustSignalStream
→ Stream<
RustSignalPack< ChangeRoute> > -
An async broadcast stream that listens for signals from Rust.
It supports multiple subscriptions.
Make sure to cancel the subscription when it's no longer needed,
such as when a widget is disposed.
final
Static Methods
-
bincodeDeserialize(
Uint8List input) → ChangeRoute -
deserialize(
BinaryDeserializer deserializer) → ChangeRoute